Get kraken historial data
=========================

This is an utility to download and update kraken data Thankyou to
pykrakenapi for his throtlling engine

Licence
-------

GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007
